HandlerFactory typedef

HandlerFactory = Handler Function(BaseCRDTDocument doc, String id)

A factory that instantiates a Handler of a specific runtime type for a given BaseCRDTDocument and handler id.

Registered on the document and used to rebuild nested handlers on a peer that only received the Changes/Snapshot, without prior knowledge of the document structure.

Implementation

typedef HandlerFactory = Handler<dynamic> Function(
  BaseCRDTDocument doc,
  String id,
);