HandlerUpdate<D> class sealed

One event in the delta stream of a handler.

A consumer seeds its projection from a HandlerReset, then keeps it up to date from the HandlerDelta events that follow. It never has to read the handler's value again.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq → int
The sequence number of this event for the handler that emitted it.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited