MapEntryRemoved<T> class final

The key is gone.

Inheritance

Constructors

MapEntryRemoved({required T previous})
The key was removed, dropping previous.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
previous → T
What the key held before it was removed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override