kind property
Operation kind, with the stamped flag already stripped.
Only meaningful together with handlerType: the same value means different things for two different handlers.
Implementation
final int kind;
Operation kind, with the stamped flag already stripped.
Only meaningful together with handlerType: the same value means different things for two different handlers.
final int kind;